import 'package:flutter/material.dart';
import '../BubbleDesign/whatsapp_arrow.dart';
import '../bubble_text.dart';
import '../dismissable_bubble.dart';
import '../seenStatus.dart';

class ChatBubbleWithoutAvatar extends StatelessWidget {
  
  const  ChatBubbleWithoutAvatar({
    required this.isMe,
    required this.message,
    required this.constraints,
    required this.senderBgColor,
    required this.receiverBgColor,
    required this.isNextMessageFromSameSender,
    required this.pointer,
    required this.ack,
    required this.time,
    required this.timeLabelColor,
    required this.textColor
  });

  final bool isMe;
  final String message;
  final BoxConstraints constraints;
  final Color senderBgColor;
  final Color receiverBgColor;
  final bool isNextMessageFromSameSender;
  final bool pointer;
  final Widget ack;
  final String time;
  final Color timeLabelColor;
  final Color textColor;

@override
  Widget build(BuildContext context) {
    /// final size = MediaQuery.of(context).size;
    return DismssibleBubble(
      isMe: isMe,
      message: message,
      child: Wrap(
        children: [
          Stack(
            children: [
              Align(
                alignment: isMe ? Alignment.bottomRight : Alignment.bottomLeft,
                child: Stack(
                  clipBehavior: Clip.none,
                  children: [
                    Column(
                      children: [
                        Container(
                        constraints: BoxConstraints(
                          maxWidth: constraints.maxWidth * 0.8,
                        ),
                        margin: EdgeInsets.only(
                              top: isNextMessageFromSameSender ? 2 : 10,
                              bottom: 1,
                            ),
                        decoration: BoxDecoration(
                              color: isMe ? senderBgColor: receiverBgColor,
                              borderRadius: BorderRadius.only(
                                topLeft: const Radius.circular(9),
                                topRight: const Radius.circular(9),
                                bottomLeft: isMe
                                    ? const Radius.circular(9)
                                    : const Radius.circular(9),
                                bottomRight: const Radius.circular(9),
                              ),
                              boxShadow: [
                                BoxShadow(
                                  color: Colors.black.withOpacity(0.13),
                                  blurRadius: 1,
                                  offset: const Offset(0,1),
                                ),
                              ],
                            ),
                        child: Padding(
                          key: key,
                          padding: const EdgeInsets.symmetric(horizontal: 10),
                          child: Wrap(
                            crossAxisAlignment: WrapCrossAlignment.end,
                            runAlignment: WrapAlignment.end,
                            alignment: WrapAlignment.end,
                            spacing: 18,
                            children: [
                              Padding(
                                padding: const EdgeInsets.only(top: 5.0, bottom: 6.0),
                                child: BubbleText(text: message, isMe: isMe,textColor:textColor),
                              ),
                              Padding(
                                padding: const EdgeInsets.only(bottom: 0.0),
                                child: SeenStatus(
                                  isMe: isMe,
                                  time: time,
                                  dateTextColor: timeLabelColor,
                                  messageAck: ack
                                ),
                              ),
                            ],
                          ),
                        ),
                       ),
                      ],
                    ),
    
                  if (isMe && !isNextMessageFromSameSender && pointer)
                      Positioned(
                        right: -8,
                        top: 19,
                        child: CustomPaint(
                          painter: WhatsAppTrianglePainter(isLeft: false, bg: isMe ? senderBgColor: receiverBgColor),
                          size: const Size(12, 12),
                        ),
                      ),
                    if (!isMe  && !isNextMessageFromSameSender && pointer)
                      Positioned(
                        left: -8,
                        top: 19,
                        child: CustomPaint(
                          painter: WhatsAppTrianglePainter(isLeft: true,  bg: isMe ? senderBgColor: receiverBgColor),
                          size: Size(12, 12),
                        ),
                      ),
                  ]
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }
}
